## Arctic Benchmarks

Benchmarks are located in the [benchmarks/](benchmarks/) directory. You must install [ASV](https://github.com/spacetelescope/asv/) to run the benchmarks. It can be installed with pip, or cloned from github and built locally (this is preferred).  A config file is provided as well [asv.conf.json](asv.conf.json). To run the benchmarks, simply run 'asv run'. More information on ASV is provided in their [documentation](http://asv.readthedocs.org/en/latest/using.html).